pub fn chest_item_choose(ctx: &ChestItemChooseCtx<'_>) -> Result<Option<Uuid>>Expand description
Plinko item override: the mimic item by next_mimic_item_code, else the
per-slot fallback for the first slot of the current inventory level that
the character has no item for, else None (roll by weights).